@@ -45,7 +45,7 @@
                             var = double(1), PACKAGE = "vegan")$var
                 tmp[i] <- 1 - invar/totvar
             }
-            pval.this <- sum(tmp > r.this)/permutations
+            pval.this <- (sum(tmp > r.this) + 1)/(permutations + 1)
             pval <- c(pval, pval.this)
         }
     }
