@@ -1,10 +1,10 @@
 `ordiGetData` <-
 function (call, env) 
 {
-    call$scale <- call$distance <- call$comm <- call$add <- NULL
+    call$scale <- call$distance <- call$comm <- call$add <-
+        call$sqrt.dist <- NULL
     call$na.action <- na.pass
     call[[2]] <- NULL
     call[[1]] <- as.name("model.frame")
     eval(call, env)
 }
-
