@@ -23,17 +23,8 @@
     summ$partial.chi <- object$pCCA$tot.chi
     summ$constr.chi <- object$CCA$tot.chi
     summ$unconst.chi <- object$CA$tot.chi
-    summ$ev.con <- object$CCA$eig
-    summ$ev.uncon <- object$CA$eig
-    ev.account <- summ$tot.chi
-    if (!is.null(object$pCCA)) 
-        ev.account <- ev.account - summ$partial.chi
-    if (!is.null(object$CCA))
-        summ$ev.con.account <- cumsum(summ$ev.con)/ev.account
-    summ$ev.uncon.account <-
-        (max(summ$constr.chi, 0) + cumsum(summ$ev.uncon))/ev.account
-    if (!is.null(object$CCA))
-        summ$cca.acc <- cumsum(summ$ev.con)/summ$constr.chi
+    summ$cont <- summary(eigenvals(object))
+    summ$concont <- summary(eigenvals(object, constrained = TRUE))
     summ$ev.head <- c(summ$ev.con, summ$ev.uncon)[1:axes]
     summ$scaling <- scaling
     summ$digits <- digits
